@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -27,6 +27,7 @@
 #include <KLocalizedString>
 #include <QDate>
 #include <QLocale>
+#include <QRegularExpression>
 
 using KMime::Types::AddrSpecList;
 using namespace KSieveUi;
@@ -42,7 +43,7 @@ static inline QString dotstuff(QString s)     // krazy:exclude=passbyvalue
 
 static inline QString stringReplace(QString s)
 {
-    s = s.replace(QRegExp(QLatin1String("[\n\t]+")), QStringLiteral(" "));
+    s = s.replace(QRegularExpression(QStringLiteral("[\n\t]+")), QStringLiteral(" "));
     return s.replace(QLatin1Char('\"'), QStringLiteral("\\\""));
 }
 
@@ -62,10 +63,9 @@ QString KSieveUi::VacationUtils::mailAction(KSieveUi::VacationUtils::MailAction
         return i18n("Redirect to");
     case CopyTo:
         return i18n("Copy to");
-    default:
-        qCWarning(LIBKSIEVE_LOG) << "Unknown mail action" << action;
-        return i18n("Unknown action");
     }
+    Q_UNREACHABLE();
+    return {};
 }
 
 KSieveUi::VacationUtils::MailAction KSieveUi::VacationUtils::defaultMailAction()
@@ -283,6 +283,7 @@ QString KSieveUi::VacationUtils::composeScript(const Vacation &vacation)
     if (!vacation.aliases.empty()) {
         addressesArgument += QStringLiteral(":addresses [ ");
         QStringList sl;
+        sl.reserve(vacation.aliases.count());
         AddrSpecList::const_iterator end = vacation.aliases.constEnd();
         for (AddrSpecList::const_iterator it = vacation.aliases.begin(); it != end; ++it) {
             sl.push_back(QLatin1Char('"') + (*it).asString().replace(QLatin1Char('\\'), QStringLiteral("\\\\")).replace(QLatin1Char('"'), QStringLiteral("\\\"")) + QLatin1Char('"'));
